pub struct Invite {
pub from: Option<Jid>,
pub to: Option<Jid>,
pub reason: Option<String>,
}Expand description
Mediated invite
Fields
from: Option<Jid>Sender.
This is only populated for invites which have been mediated by a MUC and sent to the invitee.
to: Option<Jid>Recipient.
This is only populated for requests to mediate an invite through a MUC, before forwarding it to the invitee.
reason: Option<String>The optional reason for the invite.